=================
Why this Package?
=================

So, why would one opt for this Package?

It is **easy** to *install* (using pip) and intuitive to *use*.

**Python Object Getter** features TODO which compared to 3rd party
package TODO, TODO.

Well-tested against multiple Python Interpreter versions (3.6 - 3.10),
tested on both *Linux* (Ubuntu) and *Darwin* (Macos) platforms.

Tests trigger automatically on **CI**.
The package's releases follow **Semantic Versioning**.
